==> tasks-v1.8.8.zip: tasks/messages/ja/base.php <==
<?php

return [
    '1 Day before' => '1日前',
    '1 Month before' => '1ヶ月前',
    '1 Week before' => '1週間前',
    '2 Days before' => '2日前',
    '2 Weeks before' => '2週間前',
    '3 Weeks before' => '3週間前',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>割り当てられたユーザー</strong>は、このタスクを処理できます。',
    '<strong>Confirm</strong> task deletion' => 'タスクの削除の <strong>確認</strong>',
    '<strong>Create</strong> task list' => 'タスク リストの <strong>作成</strong>',
    '<strong>Edit</strong> task' => 'タスクの <strong>編集</strong>',
    '<strong>Edit</strong> task list' => 'タスクリストの <strong>編集</strong>',
    '<strong>New</strong> Task' => '<strong>新しい</strong> タスク',
    '<strong>Task</strong> Overview' => '<strong>タスク</strong> の概要',
    '<strong>Tasks</strong>' => '<strong>タスク</strong>',
    '<strong>Tasks</strong> module configuration' => '<strong>タスク</strong> モジュールの構成',
    '<strong>Your</strong> tasks' => '<strong>あなたの</strong> タスク',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'ウィジェットはストリームのサイドバーに追加される要素です。 この場合ユーザーにタスクの簡単な概要を提供します。',
    'Accept Task' => 'タスクを許可',
    'Add Deadline to space calendar' => 'スペース カレンダーに期限を追加する',
    'Add checkpoint...' => 'チェックポイントを追加...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'タスクにチェックポイントを追加して、タスクを完了する為に必要な個々のステップを強調します。',
    'Add entry to main navigation' => 'メイン ナビゲーションにエントリを追加',
    'Add reminder' => 'リマインダーを追加',
    'Add responsible users' => '担当ユーザーを追加する',
    'Add schedule to the space calendar' => 'スペース カレンダーにスケジュールを追加する',
    'Add task' => 'タスクを追加',
    'Add to space calendar' => 'スペース カレンダーに追加',
    'Additional options' => '追加オプション',
    'All Day' => '終日',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'ユーザーが新しいタスクを作成できるようにします。ユーザーは自分のタスクの編集と削除のみを行う事ができます',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'タスクとリストの作成、削除、編集、及びタスクとリストの並べ替えをユーザーに許可します',
    'Allows the user to process unassigned tasks' => 'ユーザーが割り当てられていないタスクを処理できるようにします',
    'Already requested' => '既にリクエスト済み',
    'Any user with a "Process unassigned tasks" permission can work on this task' => '"割り当てられていないタスクの処理" 権限を持つすべてのユーザーは、このタスクに取り組むことができます',
    'Anyone can work on this task!' => '誰でもこのタスクに取り組む事ができます',
    'Assign myself' => '自分自身を割り当てる',
    'Assign users' => 'ユーザーに割り当てる',
    'Assigned' => 'アサインされた',
    'Assigned users' => '割り当てられたユーザー',
    'Assignment' => '割り当て',
    'Assignments:' => '割り当て：',
    'At least 1 Hour before' => '1時間前まで',
    'At least 2 Hours before' => '2時間前まで',
    'Attachments' => '添付ファイル',
    'Begin Task' => 'タスクの開始',
    'Checklist Items' => 'チェックリスト項目',
    'Checklist:' => 'チェックリスト：',
    'Checkpoints' => 'チェックポイント',
    'Choose if you want the module to appear in the main navigation.' => 'モジュールをメイン ナビゲーションに表示するかどうかを選択します。',
    'Close' => '閉じる',
    'Color' => '色',
    'Completed' => '完了した',
    'Completed lists' => '完成したリスト',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '特定の要件とニーズを満たすようにタスク モジュールを構成します。個々の設定を定義して、例えばウィジェットを表示するかどうかを決定できます。',
    'Continue Review' => 'レビューを続ける',
    'Create tasks' => 'タスクを作成する',
    'Created by me' => '私が作成したもの',
    'Date' => '日付',
    'Deadline at' => 'デッドライン',
    'Deadline: ' => '締め切り：',
    'Delete' => '削除',
    'Delete list' => 'リストを削除',
    'Description' => '説明',
    'Do not remind' => 'リマインダーしない',
    'Do you really want to delete this task?' => '本当にこのタスクを削除しますか？',
    'Don\'t add to calendar' => 'カレンダーに追加しない',
    'Drag entry' => 'ドラッグエントリー',
    'Edit' => '編集',
    'Edit item (empty field will be removed)...' => '項目を編集 (空のフィールドは削除されます)...',
    'Edit list' => 'リストを編集',
    'End' => '終了',
    'End Date' => '終了日',
    'End Time' => '終了時間',
    'End date' => '終了日',
    'End time must be after start time!' => '終了時刻は開始時刻より後になるように設定してください！',
    'Extend deadline request' => '期限延長申請',
    'Filter' => 'フィルター',
    'Filter by status' => 'ステータスで絞り込む',
    'Filter by title' => 'タイトルで絞り込む',
    'Filter tasks' => 'タスクのフィルタ',
    'Finish Task' => 'タスクを終了',
    'General' => '一般設定',
    'General Settings' => '基本設定',
    'Hide this list once all tasks are completed' => '全てのタスクが完了したら、このリストを非表示にします',
    'I\'m assigned' => '私がアサインされたもの',
    'I\'m responsible' => '私に責任があるもの',
    'If empty any user can complete the task.' => '空の場合、すべてのユーザーがタスクを完了できます。',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '割り当てられたユーザーが選択されていない場合、割り当てられていないタスクを処理する権限を持つすべてのスペース メンバーがタスクを処理できます。',
    'In Progress' => '継続中',
    'In Review' => 'レビュー注',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'レビュー オプションが有効な場合、<strong>責任者</strong>はこのタスクをレビューし完了する前に拒否または確認する必要があります。',
    'Invalid task list selection.' => '無効なタスク リストの選択。',
    'Let Task Review' => 'タスクをレビューする',
    'Main Navigation' => 'メインナビゲーション',
    'Manage tasks' => 'タスクを管理する',
    'Maximum number of entries in widget' => 'ウィジェットの最大エントリ数',
    'Module Widget' => 'モジュールウィジェット',
    'New list or search' => '新しいリストまたは検索',
    'No Scheduling set for this Task' => 'このタスクはスケジュールが設定されていません',
    'No pending tasks found' => '保留中のタスクが見つかりません',
    'No results found for the given filter.' => '指定されたフィルターの結果は見つかりませんでした。',
    'Open Task' => 'タスクを開く',
    'Other Tasks' => 'その他のタスク',
    'Overdue' => '期限切れ',
    'Overview' => '概要',
    'Parent Task' => '親タスク',
    'Pending' => '保留',
    'Pending Review' => 'レビューが保留',
    'Process unassigned tasks' => '割り当てられていないタスクを処理する',
    'Ready For Review' => 'レビュー準備完了',
    'Receive Notifications for Task Reminder.' => 'タスク リマインダーの通知を受け取ります。',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'タスクの通知を受け取ります (期限の更新、ステータスの変更など)',
    'Reject Task' => 'タスクを拒否',
    'Remind Mode' => 'リマインドモード',
    'Reminder' => 'リマインダー',
    'Reminder sent' => 'リマインダーを送信しました',
    'Reminders' => 'リマインダー',
    'Request extension' => '延長申請',
    'Request sent' => 'リクエストを送信しました',
    'Reset Task' => 'タスクをリセット',
    'Responsible' => '責任あり',
    'Responsible users' => '責任あるユーザー',
    'Review by responsible user required' => '責任者によるレビューが必要',
    'Scheduling' => 'スケジューリング',
    'Show widget in Spaces' => 'スペース でウィジェットを表示',
    'Show widget on Dashboard' => 'ダッシュボードにウィジェットを表示',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'さらに {count} 個の完了した {countTasks,plural,=1{task} other{task}} を表示',
    'Sort Order' => '並べ替え順序',
    'Sort order' => '並び順',
    'Spaces' => 'スペース',
    'Start' => '開始',
    'Start Date' => '開始日',
    'Start Time' => '開始時間',
    'Start date' => '開始日',
    'Starting at' => '開始',
    'Status' => 'ステータス',
    'Task' => 'タスク',
    'Task List' => 'タスクリスト',
    'Task Users have been notified' => 'タスク ユーザーに通知済み',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'スペース {spaceName} のタスク {task} は {dateTime} に終了します。',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'スペース {spaceName} のタスク {task} は {dateTime} に開始されます。',
    'Tasks' => 'タスク',
    'Tasks: Reminder' => 'タスク：リマインダー',
    'This task can only be processed by assigned and responsible users.' => 'このタスクは割り当てられた責任のあるユーザーのみが処理できます。',
    'This task requires to be reviewed by a responsible' => 'このタスクは責任者によるレビューが必要です',
    'Time Zone' => 'タイムゾーン',
    'Title' => 'タイトル',
    'Title and Color' => 'タイトルと色',
    'Title of your task list' => 'タスク リストのタイトル',
    'Today' => '今日',
    'Unsorted' => '未分類',
    'View Online' => 'オンラインで見る',
    'You are assigned!' => 'あなたは割り当てられています！',
    'You are responsible!' => 'あなたは責任があります！',
    'You have insufficient permissions to perform that operation!' => 'あなたはその操作を実行するための十分な権限を持っている！',
    'Your Reminder for task {task}' => 'タスク {task} のリマインダー',
    'ending Review' => 'レビューを終了',
    'view all' => '全て見る',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# day} other{# days}}日残っています',
    '{displayName} is assigned to this task' => '{displayName} がこのタスクに割り当てられています',
    '{displayName} is responsible for this task' => '{displayName} がこのタスクを担当しています',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} の責任者としてあなたを割り当てました。',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} にあなたを割り当てました。',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} はスペース {spaceName} でタスク {task} を完了しました。',
    '{userName} completed task {task}.' => '{userName} さんがタスク {task} を完了しました。',
    '{userName} finished task {task}.' => '{userName} さんがタスク {task} を完了しました。',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} の締め切りを変更しました。',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} がスペース {spaceName} でタスク {task} を再開しました。',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} は、スペース {spaceName} のタスク {task} を未完了として却下しました。',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} は、スペース {spaceName} のタスク {task} を完了としてマークしました。',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} の期限延長をリクエストしています。',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} を確認するように要求しています。',
    '{userName} reset task {task}.' => '{userName} さんがタスク {task} をリセットしました。',
    '{userName} reviewed task {task}.' => '{userName} さんがタスク {task} を確認しました。',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} でタスク {task} の作業を開始しました。',
    '{userName} works on task {task}.' => '{userName} はタスク {task} に取り組んでいます。',
    'Task content ID' => '',
];

==> tasks-v1.9.1.zip: tasks/messages/ja/base.php <==
<?php

return [
    '1 Day before' => '1日前',
    '1 Month before' => '1ヶ月前',
    '1 Week before' => '1週間前',
    '2 Days before' => '2日前',
    '2 Weeks before' => '2週間前',
    '3 Weeks before' => '3週間前',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>割り当てられたユーザー</strong>は、このタスクを処理できます。',
    '<strong>Confirm</strong> task deletion' => 'タスクの削除の <strong>確認</strong>',
    '<strong>Create</strong> task list' => 'タスク リストの <strong>作成</strong>',
    '<strong>Edit</strong> task' => 'タスクの <strong>編集</strong>',
    '<strong>Edit</strong> task list' => 'タスクリストの <strong>編集</strong>',
    '<strong>New</strong> Task' => '<strong>新しい</strong> タスク',
    '<strong>Task</strong> Overview' => '<strong>タスク</strong> の概要',
    '<strong>Tasks</strong>' => '<strong>タスク</strong>',
    '<strong>Tasks</strong> module configuration' => '<strong>タスク</strong> モジュールの構成',
    '<strong>Your</strong> tasks' => '<strong>あなたの</strong> タスク',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'ウィジェットはストリームのサイドバーに追加される要素です。 この場合ユーザーにタスクの簡単な概要を提供します。',
    'Accept Task' => 'タスクを許可',
    'Add Deadline to space calendar' => 'スペース カレンダーに期限を追加する',
    'Add checkpoint...' => 'チェックポイントを追加...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'タスクにチェックポイントを追加して、タスクを完了する為に必要な個々のステップを強調します。',
    'Add entry to main navigation' => 'メイン ナビゲーションにエントリを追加',
    'Add reminder' => 'リマインダーを追加',
    'Add responsible users' => '担当ユーザーを追加する',
    'Add schedule to the space calendar' => 'スペース カレンダーにスケジュールを追加する',
    'Add task' => 'タスクを追加',
    'Add to space calendar' => 'スペース カレンダーに追加',
    'Additional options' => '追加オプション',
    'All Day' => '終日',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'ユーザーが新しいタスクを作成できるようにします。ユーザーは自分のタスクの編集と削除のみを行う事ができます',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'タスクとリストの作成、削除、編集、及びタスクとリストの並べ替えをユーザーに許可します',
    'Allows the user to process unassigned tasks' => 'ユーザーが割り当てられていないタスクを処理できるようにします',
    'Already requested' => '既にリクエスト済み',
    'Assign myself' => '自分自身を割り当てる',
    'Assign users' => 'ユーザーに割り当てる',
    'Assigned users' => '割り当てられたユーザー',
    'Assignment' => '割り当て',
    'At least 1 Hour before' => '1時間前まで',
    'At least 2 Hours before' => '2時間前まで',
    'Attachments' => '添付ファイル',
    'Begin Task' => 'タスクの開始',
    'Checklist Items' => 'チェックリスト項目',
    'Checklist:' => 'チェックリスト：',
    'Checkpoints' => 'チェックポイント',
    'Choose if you want the module to appear in the main navigation.' => 'モジュールをメイン ナビゲーションに表示するかどうかを選択します。',
    'Close' => '閉じる',
    'Color' => '色',
    'Completed' => '完了した',
    'Completed lists' => '完成したリスト',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => '特定の要件とニーズを満たすようにタスク モジュールを構成します。個々の設定を定義して、例えばウィジェットを表示するかどうかを決定できます。',
    'Continue Review' => 'レビューを続ける',
    'Create tasks' => 'タスクを作成する',
    'Created by me' => '私が作成したもの',
    'Date' => '日付',
    'Deadline: ' => '締め切り：',
    'Delete' => '削除',
    'Delete list' => 'リストを削除',
    'Description' => '説明',
    'Do not remind' => 'リマインダーしない',
    'Do you really want to delete this task?' => '本当にこのタスクを削除しますか？',
    'Don\'t add to calendar' => 'カレンダーに追加しない',
    'Edit' => '編集',
    'Edit item (empty field will be removed)...' => '項目を編集 (空のフィールドは削除されます)...',
    'Edit list' => 'リストを編集',
    'End' => '終了',
    'End Date' => '終了日',
    'End Time' => '終了時間',
    'End date' => '終了日',
    'End time must be after start time!' => '終了時刻は開始時刻より後になるように設定してください！',
    'Extend deadline request' => '期限延長申請',
    'Filter' => 'フィルター',
    'Filter by status' => 'ステータスで絞り込む',
    'Filter by title' => 'タイトルで絞り込む',
    'Filter tasks' => 'タスクのフィルタ',
    'Finish Task' => 'タスクを終了',
    'General' => '一般設定',
    'General Settings' => '基本設定',
    'Hide this list once all tasks are completed' => '全てのタスクが完了したら、このリストを非表示にします',
    'I\'m assigned' => '私がアサインされたもの',
    'I\'m responsible' => '私に責任があるもの',
    'If empty any user can complete the task.' => '空の場合、すべてのユーザーがタスクを完了できます。',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => '割り当てられたユーザーが選択されていない場合、割り当てられていないタスクを処理する権限を持つすべてのスペース メンバーがタスクを処理できます。',
    'In Progress' => '継続中',
    'In Review' => 'レビュー注',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'レビュー オプションが有効な場合、<strong>責任者</strong>はこのタスクをレビューし完了する前に拒否または確認する必要があります。',
    'Invalid task list selection.' => '無効なタスク リストの選択。',
    'Let Task Review' => 'タスクをレビューする',
    'Main Navigation' => 'メインナビゲーション',
    'Manage tasks' => 'タスクを管理する',
    'Maximum number of entries in widget' => 'ウィジェットの最大エントリ数',
    'Module Widget' => 'モジュールウィジェット',
    'New list or search' => '新しいリストまたは検索',
    'No Scheduling set for this Task' => 'このタスクはスケジュールが設定されていません',
    'No pending tasks found' => '保留中のタスクが見つかりません',
    'No results found for the given filter.' => '指定されたフィルターの結果は見つかりませんでした。',
    'Open Task' => 'タスクを開く',
    'Other Tasks' => 'その他のタスク',
    'Overdue' => '期限切れ',
    'Overview' => '概要',
    'Parent Task' => '親タスク',
    'Pending' => '保留',
    'Pending Review' => 'レビューが保留',
    'Process unassigned tasks' => '割り当てられていないタスクを処理する',
    'Ready For Review' => 'レビュー準備完了',
    'Receive Notifications for Task Reminder.' => 'タスク リマインダーの通知を受け取ります。',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'タスクの通知を受け取ります (期限の更新、ステータスの変更など)',
    'Reject Task' => 'タスクを拒否',
    'Remind Mode' => 'リマインドモード',
    'Reminder' => 'リマインダー',
    'Reminder sent' => 'リマインダーを送信しました',
    'Reminders' => 'リマインダー',
    'Request extension' => '延長申請',
    'Request sent' => 'リクエストを送信しました',
    'Reset Task' => 'タスクをリセット',
    'Responsible' => '責任あり',
    'Responsible users' => '責任あるユーザー',
    'Review by responsible user required' => '責任者によるレビューが必要',
    'Scheduling' => 'スケジューリング',
    'Show widget in Spaces' => 'スペース でウィジェットを表示',
    'Show widget on Dashboard' => 'ダッシュボードにウィジェットを表示',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'さらに {count} 個の完了した {countTasks,plural,=1{task} other{task}} を表示',
    'Sort Order' => '並べ替え順序',
    'Sort order' => '並び順',
    'Spaces' => 'スペース',
    'Start' => '開始',
    'Start Date' => '開始日',
    'Start Time' => '開始時間',
    'Start date' => '開始日',
    'Starting at' => '開始',
    'Status' => 'ステータス',
    'Task' => 'タスク',
    'Task List' => 'タスクリスト',
    'Task Users have been notified' => 'タスク ユーザーに通知済み',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'スペース {spaceName} のタスク {task} は {dateTime} に終了します。',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'スペース {spaceName} のタスク {task} は {dateTime} に開始されます。',
    'Tasks' => 'タスク',
    'Tasks: Reminder' => 'タスク：リマインダー',
    'This task requires to be reviewed by a responsible' => 'このタスクは責任者によるレビューが必要です',
    'Time Zone' => 'タイムゾーン',
    'Title' => 'タイトル',
    'Title and Color' => 'タイトルと色',
    'Title of your task list' => 'タスク リストのタイトル',
    'Today' => '今日',
    'Unsorted' => '未分類',
    'View Online' => 'オンラインで見る',
    'You have insufficient permissions to perform that operation!' => 'あなたはその操作を実行するための十分な権限を持っている！',
    'Your Reminder for task {task}' => 'タスク {task} のリマインダー',
    'view all' => '全て見る',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{# day} other{# days}}日残っています',
    '{displayName} is assigned to this task' => '{displayName} がこのタスクに割り当てられています',
    '{displayName} is responsible for this task' => '{displayName} がこのタスクを担当しています',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} の責任者としてあなたを割り当てました。',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} にあなたを割り当てました。',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} はスペース {spaceName} でタスク {task} を完了しました。',
    '{userName} completed task {task}.' => '{userName} さんがタスク {task} を完了しました。',
    '{userName} finished task {task}.' => '{userName} さんがタスク {task} を完了しました。',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} の締め切りを変更しました。',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} がスペース {spaceName} でタスク {task} を再開しました。',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} は、スペース {spaceName} のタスク {task} を未完了として却下しました。',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} は、スペース {spaceName} のタスク {task} を完了としてマークしました。',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} の期限延長をリクエストしています。',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} のタスク {task} を確認するように要求しています。',
    '{userName} reset task {task}.' => '{userName} さんがタスク {task} をリセットしました。',
    '{userName} reviewed task {task}.' => '{userName} さんがタスク {task} を確認しました。',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} は、スペース {spaceName} でタスク {task} の作業を開始しました。',
    '{userName} works on task {task}.' => '{userName} はタスク {task} に取り組んでいます。',
    'Assignments' => '',
    'Deadline' => '',
    'ID' => '',
    'Request Review' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
